@@ -1,31 +1,89 @@
 ( cd opt/kde/share/doc/HTML/ru/ark ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ark ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdm ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kig ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/juk ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kpf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kpf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ktuberling ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/amor ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/amor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/karm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/karm ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kate ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kate ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdvi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdvi ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kgpg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmag ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmid ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmid ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmix ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kodo ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kolf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kolf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kpdf ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kppp ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/krdc ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/krec ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/krec ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kscd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kscd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kalzium ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kalzium ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kbattleship ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kfloppy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/cervisia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/cervisia ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kandy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kandy ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcalc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcalc ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcron ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdict ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kedit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kedit ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kjots ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kjots ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmail ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmail ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmoon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmoon ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kooka ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kooka ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kuser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kuser ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kwin4 ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/lskat ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmousetool ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konsole ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/khelpcenter/quickstart ; rm -rf common )
@@ -42,12 +100,16 @@
 ( cd opt/kde/share/doc/HTML/ru/ksirtet ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/kwuftpd ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kwallet ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kweather ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kweather ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/aktion ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/aktion ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/kxconfig ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/kxconfig ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kaddressbook ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf qpl-license.html )
@@ -84,6 +146,8 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doxygen.css )
@@ -98,12 +162,16 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/ru/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf fdl-license.html )
@@ -134,50 +202,78 @@
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/ru/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/ru/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kdm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/bell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/cache ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/background ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/crypto ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/windowmanagement ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/artsbuilder ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/artsbuilder ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/konq-plugins/crashes ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
-( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; rm -rf common )
-( cd opt/kde/share/doc/HTML/ru/konq-plugins/babel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kbabel ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kamera ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kamera ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdeprint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdeprint ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kgamma ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kdevelop ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kicker ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/klines ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kmines ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmouth ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kmplot ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kpager ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kopete ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/ktalkd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/ktalkd ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kstars ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kstars ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ktouch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ktouch ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/megami ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/megami ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/noatun ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/ksplashml ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/quanta ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kghostview ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kghostview ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kenolaba ; rm -rf common )
@@ -188,20 +284,46 @@
 ( cd opt/kde/share/doc/HTML/ru/kworldclock ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kteatime ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kteatime ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/dma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pci ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/usb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/nics ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/scsi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/interrupts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/devices ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/xserver ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/samba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/sound ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/partitions ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/memory ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/ioports ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/protocols ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
+( cd opt/kde/share/doc/HTML/ru/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/ru/umbrello ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/ru/konqueror ; ln -sf /opt/kde/share/doc/HTML/ru/common common )
 ( cd opt/kde/share/doc/HTML/ru/atlantik ; rm -rf common )
